BandwidthController

Struct BandwidthController 

pub struct BandwidthController<St> { /* private fields */ }

Implementations

Source

impl<St: Storage> BandwidthController<St>

pub fn new(storage: St) -> Self

pub fn with_credential_public_data_fetcher( self, fetcher: impl CredentialPublicDataFetcher + 'static, ) -> Self

pub fn get_request_sender(&self) -> BandwidthControllerRequestSender

Get the request channel used to send request to the controller. Request are handled only if the BandwidthController is running using run

pub async fn get_next_usable_ticketbook( &self, ticketbook_type: TicketType, tickets: u32, ) -> Result<Option<RetrievedTicketbook>, BandwidthControllerError>

Tries to retrieve one of the stored, unused credentials for the given type that hasn’t yet expired.

pub async fn attempt_revert_ticket_usage( &self, info: PreparedCredentialMetadata, ) -> Result<bool, BandwidthControllerError>

pub async fn get_aggregate_verification_key( &self, epoch_id: EpochId, ) -> Result<Option<VerificationKeyAuth>, BandwidthControllerError>

pub async fn get_coin_index_signatures( &self, epoch_id: EpochId, ) -> Result<Option<Vec<AnnotatedCoinIndexSignature>>, BandwidthControllerError>

pub async fn get_expiration_date_signatures( &self, epoch_id: EpochId, expiration_date: Date, ) -> Result<Option<Vec<AnnotatedExpirationDateSignature>>, BandwidthControllerError>

pub async fn ensure_global_data( &self, epoch_id: EpochId, expiration_date: Date, ) -> Result<(), BandwidthControllerError>

Ensures all global ecash signing materials for the given epoch and expiration date are present in local storage, fetching and persisting any that are missing.

pub async fn prepare_ecash_ticket( &self, ticketbook_type: TicketType, provider_pk: [u8; 32], tickets_to_spend: u32, spend_time: OffsetDateTime, ) -> Result<Option<PreparedCredential>, BandwidthControllerError>

pub async fn run(self, shutdown_token: ShutdownToken)

Runs the controller event loop, handling incoming requests until the request channel is closed or cancellation is requested.